==> 0.1.1.tar.gz: lib/mzanalytics_android.dart <==
import 'dart:async';
import 'package:flutter/services.dart';

class Mzanalytics_android {
  static const MethodChannel _channel =
      const MethodChannel('mzanalytics_mybmw');

  static Future<void> initEvent() async {
    try {
      _channel.invokeMethod('initEvent');
    } on PlatformException catch (e) {}
  }

  static Future<void> trackEvent(var parameter) async {
    try {
      _channel.invokeMethod('trackEvent', parameter);
    } on PlatformException catch (e) {}
  }

  static Future<void> trackPageView(var parameter) async {
    try {
      _channel.invokeMethod('trackPageView', parameter);

    } on PlatformException catch (e) {}
  }

  static Future<void> trackSiteCustomEvent(var parameter) async {
    try {
      _channel.invokeMethod('trackSiteCustomEvent', parameter);
    } on PlatformException catch (e) {}
  }

  static Future<void> trackPulse() async {
    try {
      _channel.invokeMethod('trackPulse');
    } on PlatformException catch (e) {}
  }

  static Future<String> getOaid() async {
    try {
      return _channel.invokeMethod('getOaid');
    } on PlatformException catch (e) {}
  }

  static Future<String> getCid() async {
    try {
      return _channel.invokeMethod('getCid');
    } on PlatformException catch (e) {}
  }

  static Future<String> setCd(var key, var value) async {
    try {
      return _channel.invokeMethod(
          'setCd', <String, dynamic>{'cd_key': key, "cd_value": value});
    } on PlatformException catch (e) {}
  }

  static Future<String> setCm(var key, var value) async {
    try {
      return _channel.invokeMethod(
          'setCm', <String, dynamic>{'cm_key': key, "cm_value": value});
    } on PlatformException catch (e) {}
  }

  static Future<String> deleteCd(var key) async {
    try {
      return _channel
          .invokeMethod('deleteCd', <String, dynamic>{'cd_key': key});
    } on PlatformException catch (e) {}
  }

  static Future<String> deleteCm(var key) async {
    try {
      return _channel
          .invokeMethod('deleteCm', <String, dynamic>{'cm_key': key});
    } on PlatformException catch (e) {}
  }

  static Future<Map> getCdAndCm() async {
    try {
      return _channel.invokeMethod('getCdAndCm');
    } on PlatformException catch (e) {}
  }

  static Future<bool> isAutoTrackpage() async {
    try {
      return _channel.invokeMethod('isAutoTrackpage');
    } on PlatformException catch (e) {}
  }

  static Future<List> getBlackList() async {
    try {
      return _channel.invokeMethod('getBlackList');
    } on PlatformException catch (e) {}
  }



 

 

  

  
}

==> 0.2.8.tar.gz: lib/mzanalytics_android.dart <==
import 'dart:async';
import 'package:flutter/services.dart';

///Mzanalytics_android
class MzanalyticsAndroid {
  static const MethodChannel _channel =
      const MethodChannel('mzanalytics_mybmw');

  ///initEvent
  static Future<void> initEvent() async {
    try {
      _channel.invokeMethod('initEvent');
    } on PlatformException {}
  }

  ///trackEvent
  static Future<void> trackEvent(var parameter) async {
    try {
      _channel.invokeMethod('trackEvent', parameter);
    } on PlatformException {}
  }

  ///trackPageView
  static Future<void> trackPageView(var parameter) async {
    try {
      _channel.invokeMethod('trackPageView', parameter);
    } on PlatformException {}
  }

  ///trackSiteCustomEvent
  static Future<void> trackSiteCustomEvent(var parameter) async {
    try {
      _channel.invokeMethod('trackSiteCustomEvent', parameter);
    } on PlatformException {}
  }

  ///trackPulse
  static Future<void> trackPulse() async {
    try {
      _channel.invokeMethod('trackPulse');
    } on PlatformException {}
  }

  ///handleOpenURL
  static Future<void> handleOpenURL(String url) async {
    try {
      _channel.invokeMethod('handleOpenURL', url);
    } on PlatformException {}
  }

  ///getOaid
  static Future<String> getOaid() async {
    try {
      return _channel.invokeMethod('getOaid');
    } on PlatformException {}
    return "";
  }

  ///getCid
  static Future<String> getCid() async {
    try {
      return _channel.invokeMethod('getCid');
    } on PlatformException {}
    return "";
  }

  ///setCd
  static Future<void> setCd(var key, var value) async {
    try {
      return _channel.invokeMethod(
          'setCd', <String, dynamic>{'cd_key': key, "cd_value": value});
    } on PlatformException {}
  }

  ///setCm
  static Future<void> setCm(var key, var value) async {
    try {
      return _channel.invokeMethod(
          'setCm', <String, dynamic>{'cm_key': key, "cm_value": value});
    } on PlatformException {}
  }

  ///deleteCd
  static Future<void> deleteCd(var key) async {
    try {
      return _channel
          .invokeMethod('deleteCd', <String, dynamic>{'cd_key': key});
    } on PlatformException {}
  }

  ///deleteCm
  static Future<void> deleteCm(var key) async {
    try {
      return _channel
          .invokeMethod('deleteCm', <String, dynamic>{'cm_key': key});
    } on PlatformException {}
  }

  ///getCdAndCm
  static Future<Map> getCdAndCm() async {
    try {
      return _channel.invokeMethod('getCdAndCm');
    } on PlatformException {}
    return Map();
  }

  ///isAutoTrackpage
  static Future<bool> isAutoTrackpage() async {
    try {
      return _channel.invokeMethod('isAutoTrackpage');
    } on PlatformException {}
    return false;
  }

  ///getBlackList
  static Future<List> getBlackList() async {
    try {
      return _channel.invokeMethod('getBlackList');
    } on PlatformException {}
    return [];
  }
}
